==> ks_1.3.5.tar.gz: ks/man/ks-internal.Rd <==
\name{ks-internal}
\alias{Hlscv.ab}
\alias{Hlscv.pc} 
\alias{Hlscv.vkde} 
\alias{Psi4.elem} 
\alias{Psi4.list} 
\alias{RKfun} 
\alias{Theta6.elem}
\alias{amise.mixt.2d}
\alias{bcv.mat}
\alias{clust.tree} 
\alias{dmvnorm.1d.sum} 
\alias{dmvnorm.2d.sum}
\alias{dmvnorm.2d.sum.pc}
\alias{dmvnorm.3d.sum} 
\alias{dmvnorm.4d.sum}
\alias{dmvnorm.5d.sum} 
\alias{dmvnorm.6d.sum}
\alias{dmvnorm.deriv.1d}
\alias{dmvnorm.deriv.2d} 
\alias{dmvnorm.deriv.2d.sum} 
\alias{dmvnorm.deriv.2d.xxt.sum}
\alias{dmvnorm.deriv.3d} 
\alias{dmvnorm.deriv.3d.sum}
\alias{dmvnorm.deriv.4d} 
\alias{dmvnorm.deriv.4d.sum}  
\alias{dmvnorm.deriv.5d}
\alias{dmvnorm.deriv.5d.sum}
\alias{dmvnorm.deriv.6d}
\alias{dmvnorm.deriv.6d.sum} 
\alias{dmvt} 
\alias{dupl} 
\alias{elem}
\alias{find.gridpts} 
\alias{gamse.even.2d} 
\alias{gamse.odd.2d} 
\alias{gamse.scv.2d}
\alias{gamse.scv.3d} 
\alias{gamse.scv.4d}
\alias{gamse.scv.5d}
\alias{gamse.scv.6d} 
\alias{gsamse.2d} 
\alias{gsamse.3d}
\alias{gsamse.4d} 
\alias{gsamse.5d}
\alias{gsamse.6d} 
\alias{invdupl} 
\alias{invvec} 
\alias{invvech}
\alias{invvech.cat} 
\alias{is.even}
\alias{ise.mixt.pc}
\alias{iset.mixt}
\alias{kde.grid.2d} 
\alias{kde.grid.3d}
\alias{kde.pc.grid.2d}
\alias{kde.pc.points} 
\alias{kde.points}
\alias{lambda}
\alias{list.length} 
\alias{lscv.mat} 
\alias{lscv.mat.ab}
\alias{lscv.mat.pc} 
\alias{make.grid} 
\alias{make.supp} 
\alias{matrix.sqrt} 
\alias{mise.mixt.pc}
\alias{moments.mixt} 
\alias{mvpeaks.2d}
\alias{nearest.mode} 
\alias{omega}
\alias{optnum.clust} 
\alias{permute}
\alias{permute.mat}
\alias{plot.pvkde}
\alias{plotdade.2d}
\alias{plotdade.3d}
\alias{plotkde.2d}
\alias{plotkde.3d}
\alias{plotmixt.2d}
\alias{plotmixt.3d}
\alias{points3d.rh}
\alias{pre.abram}
\alias{pre.clust} 
\alias{pre.sain}
\alias{pre.scale.pc} 
\alias{pre.sphere.pc} 
\alias{pre.vkde}
\alias{psifun1.2d}
\alias{psifun1.3d} 
\alias{psifun1.4d}
\alias{psifun1.5d} 
\alias{psifun1.6d}
\alias{psifun1.diag.5d}
\alias{psifun1.diag.6d} 
\alias{psifun2.2d}
\alias{psifun2.3d} 
\alias{psifun2.4d}
\alias{psifun2.5d}
\alias{psifun2.diag.5d}
\alias{psifun2.6d} 
\alias{psifun2.diag.6d} 
\alias{psimat.2d} 
\alias{psimat.3d}
\alias{psimat.4d}
\alias{psimat.5d}
\alias{psimat.diag.5d}
\alias{psimat.6d}
\alias{psimat.diag.6d} 
\alias{psins.2d} 
\alias{psins.3d}
\alias{psins.4d}
\alias{psins.4d.part6}
\alias{psins.4d.part8}   
\alias{psins.5d}
\alias{psins.6d}
\alias{psins.6d.part6}
\alias{psins.6d.part81}
\alias{psins.6d.part82} 
\alias{psins.6d.part83} 
\alias{psins.6d.part84}
\alias{quads3d.rh}
\alias{scv.mat} 
\alias{spheres3d.rh}
\alias{ssq.decomp}
\alias{texts3d.rh}
\alias{tr}
\alias{triangles3d.rh}
\alias{vec}
\alias{vech} 
\alias{vech.cat} 
\alias{which.mat}


\title{Internal functions in the ks library}
\description{
These functions are user-level but which the user is not required to use directly.
}


\keyword{internal}

==> ks_1.4.0.tar.gz: ks/man/ks-internal.Rd <==
\name{ks-internal}
\alias{Hlscv.ab}
\alias{Hlscv.pc} 
\alias{Hlscv.vkde} 
\alias{Psi4.elem} 
\alias{Psi4.list} 
\alias{RKfun} 
\alias{Theta6.elem}
\alias{amise.mixt.2d}
\alias{bcv.mat}
\alias{clust.tree}
\alias{dfltCounts}
\alias{dmvnorm.1d.sum} 
\alias{dmvnorm.2d.sum}
\alias{dmvnorm.2d.sum.pc}
\alias{dmvnorm.3d.sum} 
\alias{dmvnorm.4d.sum}
\alias{dmvnorm.5d.sum} 
\alias{dmvnorm.6d.sum}
\alias{dmvnorm.deriv.1d}
\alias{dmvnorm.deriv.2d} 
\alias{dmvnorm.deriv.2d.sum} 
\alias{dmvnorm.deriv.2d.xxt.sum}
\alias{dmvnorm.deriv.3d} 
\alias{dmvnorm.deriv.3d.sum}
\alias{dmvnorm.deriv.4d} 
\alias{dmvnorm.deriv.4d.sum}  
\alias{dmvnorm.deriv.5d}
\alias{dmvnorm.deriv.5d.sum}
\alias{dmvnorm.deriv.6d}
\alias{dmvnorm.deriv.6d.sum} 
\alias{dmvt}
\alias{drvkde} 
\alias{dupl} 
\alias{elem}
\alias{find.gridpts} 
\alias{gamse.even.2d} 
\alias{gamse.odd.2d} 
\alias{gamse.scv.2d}
\alias{gamse.scv.3d} 
\alias{gamse.scv.4d}
\alias{gamse.scv.5d}
\alias{gamse.scv.6d} 
\alias{gsamse.2d} 
\alias{gsamse.3d}
\alias{gsamse.4d} 
\alias{gsamse.5d}
\alias{gsamse.6d} 
\alias{invdupl} 
\alias{invvec} 
\alias{invvech}
\alias{invvech.cat} 
\alias{is.even}
\alias{ise.mixt.pc}
\alias{iset.mixt}
\alias{kde.grid.2d} 
\alias{kde.grid.3d}
\alias{kde.pc.grid.2d}
\alias{kde.pc.points} 
\alias{kde.points}
\alias{lambda}
\alias{list.length}
\alias{linbin}
\alias{linbin2D}
\alias{linbin3D}
\alias{linbin4D}
\alias{lscv.mat} 
\alias{lscv.mat.ab}
\alias{lscv.mat.pc} 
\alias{make.grid} 
\alias{make.supp} 
\alias{matrix.sqrt} 
\alias{mise.mixt.pc}
\alias{moments.mixt} 
\alias{mvpeaks.2d}
\alias{nearest.mode} 
\alias{omega}
\alias{optnum.clust} 
\alias{permute}
\alias{permute.mat}
\alias{plot.pvkde}
\alias{plotdade.2d}
\alias{plotdade.3d}
\alias{plotkde.2d}
\alias{plotkde.3d}
\alias{plotmixt.2d}
\alias{plotmixt.3d}
\alias{points3d.rh}
\alias{pre.abram}
\alias{pre.clust} 
\alias{pre.sain}
\alias{pre.scale.pc} 
\alias{pre.sphere.pc} 
\alias{pre.vkde}
\alias{psifun1.2d}
\alias{psifun1.3d} 
\alias{psifun1.4d}
\alias{psifun1.5d} 
\alias{psifun1.6d}
\alias{psifun1.diag.5d}
\alias{psifun1.diag.6d} 
\alias{psifun2.2d}
\alias{psifun2.3d} 
\alias{psifun2.4d}
\alias{psifun2.5d}
\alias{psifun2.diag.5d}
\alias{psifun2.6d} 
\alias{psifun2.diag.6d} 
\alias{psimat.2d} 
\alias{psimat.3d}
\alias{psimat.4d}
\alias{psimat.5d}
\alias{psimat.diag.5d}
\alias{psimat.6d}
\alias{psimat.diag.6d} 
\alias{psins.2d} 
\alias{psins.3d}
\alias{psins.4d}
\alias{psins.4d.part6}
\alias{psins.4d.part8}   
\alias{psins.5d}
\alias{psins.6d}
\alias{psins.6d.part6}
\alias{psins.6d.part81}
\alias{psins.6d.part82} 
\alias{psins.6d.part83} 
\alias{psins.6d.part84}
%\alias{quads3d.rh}
\alias{rhcs.clear3d}
\alias{rhcs.points3d}
\alias{rhcs.quads3d}
\alias{rhcs.spheres3d}
\alias{rhcs.texts3d}
\alias{rhcs.triangles3d}
\alias{scv.mat} 
%\alias{spheres3d.rh}
\alias{ssq.decomp}
\alias{symconv}
\alias{symconv2D}
\alias{symconv3D}
\alias{symconv4D}
%\alias{texts3d.rh}
\alias{tr}
%\alias{triangles3d.rh}
\alias{vec}
\alias{vech} 
\alias{vech.cat} 
\alias{which.mat}


\title{Internal functions in the ks library}
\description{
These functions are user-level but which the user is not required to use directly.
}


\keyword{internal}
